@@ -20,6 +20,7 @@ import re
 import math
 from os import path
 from calculate.lib.utils.dracut import Dracut
+from calculate.lib.utils.system import SystemPath
 import sys
 import getpass
 from types import StringType
@@ -135,7 +136,8 @@ def getTupleVersion(ver):
 
 def getInstalledVideo(prefix="/"):
     """Get installed video drivers"""
-    x11Drivers = path.join(prefix, "usr/lib/xorg/modules/drivers")
+    usrlib = SystemPath(prefix).usrlib
+    x11Drivers = "%s/xorg/modules/drivers" % usrlib
     return map(lambda x: x[:-7],
                filter(lambda x: x.endswith('_drv.so'),
                       listDirectory(x11Drivers)))
