@@ -34,6 +34,7 @@ from .files import (getProgPath, find, process, listDirectory, readFile,
                     FilesError, rsync_files, RsyncOptions,
                     removeDir, removeFileWithEmptyDirectory, FindFileType)
 from .tools import SavableIterator, ignore
+from .system import SystemPath
 from collections import Mapping, defaultdict
 from .common import getTupleVersion
 from contextlib import closing
@@ -1407,8 +1408,14 @@ def getlibpaths(prefix="/"):
             else:
                 yield l
     rval = list(read_ld_so_conf(path.join(prefix, "etc", "ld.so.conf")))
-    rval.append("/usr/lib")
-    rval.append("/lib")
+
+    systempath = SystemPath(prefix)
+
+    rval.append(systempath.lib)
+    rval.append(systempath.usrlib)
+    rval.append(systempath.clib)
+    rval.append(systempath.cusrlib)
+    
     return sorted(list(set([path.normpath(x) for x in rval if x])))
 
 _re_req_arches = re.compile("(\w+:\s.*?)(?=\s\w+:|$)")
